import Vue from "vue";
import VueRouter from "vue-router";
import store from '@/store'
Vue.use(VueRouter);

const routes = [
	{
		path:'/',
		name:'login',
		meta: {
			title: '冷链验证报告管理系统线上版本',
		},
		component: () => import('@/views/login/login.vue')
	},
	{
		path:'/index',
		name:'index',
		meta: {
			title: '首页',
		},
		component: () => import('@/views/layout/index.vue'),
		children: [{
			path: '/home',
			name: 'home',
			icons:'el-icon-house',
			component: () => import('@/views/home/home.vue'),
			meta: {
				title: '工作首页',
			},
		},{
			path: '/CompanyAccount',
			name: 'CompanyAccount',
			icons:'el-icon-bank-card',
			component: () => import('@/views/CompanyAccount/index.vue'),
			meta: {
				title: '公司账户',
			},
		},{
			path: '/ManagingUsers',
			name: 'ManagingUsers',
			icons:'el-icon-user',
			component: () => import('@/views/ManagingUsers/index.vue'),
			meta: {
				title: '管理用户',
			},
		},{
			path: '/companyManagement',
			name: 'companyManagement',
			icons:'el-icon-office-building',
			component: () => import('@/views/companyManagement/index.vue'),
			meta: {
				title: '公司管理',
			},
		},{
			path: '/ReportViewing',
			name: 'ReportViewing',
			icons:'el-icon-pie-chart',
			component: () => import('@/views/ReportViewing/index.vue'),
			meta: {
				title: '报告查看',
			},
		},{
			path: '/ValidationTemplate',
			name: 'ValidationTemplate',
			icons:'el-icon-magic-stick',
			component: () => import('@/views/ValidationTemplate/index.vue'),
			meta: {
				title: '验证模板管理',
			},
		},{
			path: '/calibrationCertificate',
			name: 'calibrationCertificate',
			icons:'el-icon-notebook-2',
			component: () => import('@/views/calibrationCertificate/index.vue'),
			meta: {
				title: '校准证书管理',
			},
		}]
	},{
		path: '*',
		component: () => import('@/components/404.vue'),
	}
]

const router = new VueRouter({
	mode: "history",//hash
	base: process.env.BASE_URL,
	routes,
});

//登录拦截//未登录返回到登录界面
router.beforeEach((to, from, next) => {
	if(to.name=='login'){//退出登录之后清零
		store.state.tabList = [{
			title:'工作首页',
			path:'/home',
			name:'home'
		}],
		store.state.includeTabs = []
		console.log('login了')
	}
	if(to.name!=-1 && to.name!='login'){
		store.commit('addTab',{
			title:to.meta.title,
			path:to.path,
			name:to.name
		})
	}
	next()
})

export default router;